@@ -1,19 +1,22 @@
-from typing import Any, Awaitable, Callable, Protocol, Type, TypeVar
+from typing import Any, Protocol, Type, TypeVar
 
 from didiator.interface.entities.request import Request
 from didiator.interface.handlers import HandlerType
+from didiator.middlewares.base import MiddlewareType
 
+Self = TypeVar("Self", bound="Dispatcher")
 R = TypeVar("R", bound=Request[Any])
 RRes = TypeVar("RRes")
 
-MiddlewareType = Callable[[HandlerType[R, RRes], R], Awaitable[RRes]]
-
 
 class Dispatcher(Protocol):
     @property
-    def handlers(self) -> dict[Type[Request[Any]], HandlerType[Any, Any]]:
+    def handlers(self) -> dict[Type[Request[Any]], HandlerType[Request[Any], Any]]:
         raise NotImplementedError
 
     @property
-    def middlewares(self) -> tuple[MiddlewareType[Any, Any], ...]:
+    def middlewares(self) -> tuple[MiddlewareType[Request[Any], Any], ...]:
+        raise NotImplementedError
+
+    def copy(self: Self) -> Self:
         raise NotImplementedError
