@@ -1,9 +1,11 @@
 from .command import Command
+from .event import Event
 from .request import Request
 from .query import Query
 
 __all__ = (
-    "Command",
     "Request",
+    "Command",
     "Query",
+    "Event",
 )
