@@ -1,5 +1,6 @@
 import abc
-from typing import Any, Generic, TypeVar
+from collections.abc import Awaitable, Callable
+from typing import Any, Generic, Type, TypeVar, Union
 
 from didiator.interface.entities.command import Command
 
@@ -12,4 +13,7 @@ C = TypeVar("C", bound=Command[Any])
 class CommandHandler(Handler[C, CRes], abc.ABC, Generic[C, CRes]):
     @abc.abstractmethod
     async def __call__(self, command: C) -> CRes:
-        ...
+        raise NotImplementedError
+
+
+CommandHandlerType = Union[Type[CommandHandler[C, CRes]], Callable[..., Awaitable[CRes]]]
