@@ -1,5 +1,6 @@
 import abc
-from typing import Any, Generic, TypeVar
+from collections.abc import Awaitable, Callable
+from typing import Any, Generic, Type, TypeVar, Union
 
 from didiator.interface.entities.query import Query
 
@@ -12,4 +13,7 @@ Q = TypeVar("Q", bound=Query[Any])
 class QueryHandler(Handler[Q, QRes], abc.ABC, Generic[Q, QRes]):
     @abc.abstractmethod
     async def __call__(self, query: Q) -> QRes:
-        ...
+        raise NotImplementedError
+
+
+QueryHandlerType = Union[Type[QueryHandler[Q, QRes]], Callable[..., Awaitable[QRes]]]
